All Classes and Interfaces

Class
Description
 
 
 
 
 
 
Extends Loader to override some things which are not generated directly for JRuby.
 
Represents the use of the `alias` keyword to alias a global variable.
Represents the use of the `alias` keyword to alias a method.
Represents an alternation pattern in pattern matching.
Represents the use of the `&&` operator or the `and` keyword.
Represents a set of arguments to a method or a keyword.
Flags for arguments nodes.
Represents an array literal.
Flags for array nodes.
Represents an array pattern in pattern matching.
Represents a hash key/value pair
Represents a splat in a hash literal
Represents reading a reference to a field in the previous match
Represents a begin statement.
Represents a block argument using `&`.
Represents a block local variable.
Represents a block of ruby code
Represents a block parameter of a method, block, or lambda definition.
Represents a block's parameters declaration
Represents the use of the `break` keyword.
Represents the use of the `&&=` operator on a call.
Represents a method call, in all of the various forms that can take.
Flags for call nodes.
Represents the use of an assignment operator on a call.
Represents the use of the `||=` operator on a call.
Represents assigning to a method call.
Represents assigning to a local variable in pattern matching.
Represents the use of a case statement for pattern matching.
Represents the use of a case statement.
Represents a class declaration involving the `class` keyword.
Represents the use of the `&&=` operator for assignment to a class variable.
Represents assigning to a class variable using an operator that isn't `=`.
Represents the use of the `||=` operator for assignment to a class variable.
Represents referencing a class variable.
Represents writing to a class variable in a context that doesn't have an explicit value.
Represents writing to a class variable.
Represents the use of the `&&=` operator for assignment to a constant.
Represents assigning to a constant using an operator that isn't `=`.
Represents the use of the `||=` operator for assignment to a constant.
Represents the use of the `&&=` operator for assignment to a constant path.
Represents accessing a constant through a path of `::` operators.
Represents assigning to a constant path using an operator that isn't `=`.
Represents the use of the `||=` operator for assignment to a constant path.
Represents writing to a constant path in a context that doesn't have an explicit value.
Represents writing to a constant path.
Represents referencing a constant.
Represents writing to a constant in a context that doesn't have an explicit value.
Represents writing to a constant.
Represents the use of the `defined?
Represents a method definition.
Represents an `else` clause in a `case`, `if`, or `unless` statement.
Represents an interpolated set of statements.
Represents an interpolated variable.
Flags for nodes that have unescaped content.
Represents an `ensure` clause in a `begin` statement.
 
Represents the use of the literal `false` keyword.
Represents a find pattern in pattern matching.
Represents the use of the `..` or `...` operators to create flip flops.
Represents a floating point number literal. 1.0 ^^^
Represents the use of the `for` keyword.
Represents forwarding all arguments to this method to another method.
Represents the use of the forwarding parameter in a method, block, or lambda declaration.
Represents the use of the `super` keyword without parentheses or arguments.
Represents the use of the `&&=` operator for assignment to a global variable.
Represents assigning to a global variable using an operator that isn't `=`.
Represents the use of the `||=` operator for assignment to a global variable.
Represents referencing a global variable.
Represents writing to a global variable in a context that doesn't have an explicit value.
Represents writing to a global variable.
Represents a hash literal
Represents a hash pattern in pattern matching.
Represents the use of the `if` keyword, either in the block form or the modifier form, or a ternary expression.
Represents an imaginary number literal. 1.0i ^^^^
Represents a node that is implicitly being added to the tree but doesn't correspond directly to a node in the source
Represents using a trailing comma to indicate an implicit rest parameter.
Represents the use of the `&&=` operator on a call to the `[]` method.
Represents the use of an assignment operator on a call to `[]`.
Represents the use of the `||=` operator on a call to `[]`.
Represents assigning to an index.
Represents the use of the `in` keyword in a case statement.
Represents the use of the `&&=` operator for assignment to an instance variable.
Represents assigning to an instance variable using an operator that isn't `=`.
Represents the use of the `||=` operator for assignment to an instance variable.
Represents referencing an instance variable.
Represents writing to an instance variable in a context that doesn't have an explicit value.
Represents writing to an instance variable.
Flags for integer nodes that correspond to the base of the integer.
Represents an integer number literal. 1 ^
Represents a regular expression literal that contains interpolation that is being used in the predicate of a conditional to implicitly match against the last line read by an IO object.
Represents a regular expression literal that contains interpolation.
Represents a string literal that contains interpolation.
Flags for interpolated string nodes that indicated mutability if they are also marked as literals.
Represents a symbol literal that contains interpolation
Represents an xstring literal that contains interpolation.
Represents reading from the implicit `it` local variable
Represents an implicit set of parameters through the use of the `it` keyword within a block or lambda
Represents a hash literal without opening and closing braces.
Flags for keyword hash nodes.
Represents a keyword rest parameter to a method, block, or lambda definition.
Represents using a lambda literal (not the lambda method call)
Represents the use of the `&&=` operator for assignment to a local variable.
Represents assigning to a local variable using an operator that isn't `=`.
Represents the use of the `||=` operator for assignment to a local variable.
Represents reading a local variable.
Represents writing to a local variable in a context that doesn't have an explicit value.
Represents writing to a local variable.
 
Flags for while and until loop nodes.
Represents a regular expression literal used in the predicate of a conditional to implicitly match against the last line read by an IO object.
Represents the use of the modifier `in` operator.
Represents the use of the `=>` operator.
Represents writing local variables using a regular expression match with named capture groups. /(?
Represents a node that is missing from the source and results in a syntax error.
Represents a module declaration involving the `module` keyword.
Represents a multi-target expression.
Represents a write to a multi-target expression.
Represents the use of the `next` keyword.
Represents the use of the `nil` keyword.
 
Represents the use of `**nil` inside method arguments.
 
Represents an implicit set of parameters through the use of numbered parameters within a block or lambda
Represents reading a numbered reference to a capture in the previous match
Represents an optional keyword parameter to a method, block, or lambda definition.
Represents an optional parameter to a method, block, or lambda definition.
Represents the use of the `||` operator or the `or` keyword.
Flags for parameter nodes.
Represents the list of parameters on a method, block, or lambda definition.
Represents a parenthesized expression (10 + 34) ^^^^^^^^^
Flags for parentheses nodes.
Represents the use of the `^` operator for pinning an expression in a pattern matching expression.
Represents the use of the `^` operator for pinning a variable in a pattern matching expression.
Represents the use of the `END` keyword.
Represents the use of the `BEGIN` keyword.
The top level node of any parse tree.
Flags for range and flip-flop nodes.
Represents the use of the `..` or `...` operators. 1..2 ^^^^ c if a =~ /left/ ... b =~ /right/ ^^^^^^^^^^^^^^^^^^^^^^^^^^^^
Represents a rational number literal. 1.0r ^^^^
Represents the use of the `redo` keyword.
Flags for regular expression and match last line nodes.
Represents a regular expression literal with no interpolation.
Represents a required keyword parameter to a method, block, or lambda definition.
Represents a required parameter to a method, block, or lambda definition.
Represents an expression modified with a rescue.
Represents a rescue statement.
Represents a rest parameter to a method, block, or lambda definition.
Represents the use of the `retry` keyword.
Represents the use of the `return` keyword.
Represents the `self` keyword.
This node wraps a constant write to indicate that when the value is written, it should have its shareability state modified
Flags for shareable constant nodes.
Represents a singleton class declaration involving the `class` keyword.
 
Represents the use of the `__ENCODING__` keyword.
Represents the use of the `__FILE__` keyword.
Represents the use of the `__LINE__` keyword.
Represents the use of the splat operator.
Represents a set of statements contained within some scope.
Flags for string nodes.
Represents a string literal, a string contained within a `%w` list, or plain string content within an interpolated string.
Represents the use of the `super` keyword with parentheses or arguments.
Flags for symbol nodes.
Represents a symbol literal or a symbol contained within a `%i` list.
Represents the use of the literal `true` keyword.
Represents the use of the `undef` keyword.
 
Represents the use of the `unless` keyword, either in the block form or the modifier form.
Represents the use of the `until` keyword, either in the block form or the modifier form.
 
Represents the use of the `when` keyword within a case statement.
Represents the use of the `while` keyword, either in the block form or the modifier form.
Represents an xstring literal with no interpolation.
Represents the use of the `yield` keyword.
 
JNR binding to prism.
 
 
 
 
 
 
 
 
 
 
 
The command line options that can be passed to the parser.
The forwarding options for a given scope in the parser.
Represents a scope in the parser.
The version of Ruby syntax that we should be parsing with.