Index

A B C D E F G H I L N O P R S T V W 
All Classes and Interfaces|All Packages

A

addGetsLoop(Ruby, ParseResult, boolean, boolean, boolean) - Method in class org.jruby.prism.parser.ParserPrismBase
 
alwaysFalse(Nodes.Node) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
alwaysTrue(Nodes.Node) - Method in class org.jruby.prism.builder.IRBuilderPrism
 

B

bodyFor(Nodes.RescueNode) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
Buffer(Runtime) - Constructor for class org.jruby.prism.parser.ParserBindingPrism.Buffer
 
build(Variable, Nodes.Node) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
build(ParseResult) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
build(Nodes.Node) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
buildAssignment(Map<Nodes.Node, Operand>, List<Tuple<Nodes.Node, ResultInstr>>) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
buildAssignment(Nodes.Node, Operand) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
buildAssocs(Label, Operand, Variable, Nodes.HashPatternNode, boolean, boolean, Variable, boolean, Variable) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
buildAttrAssignAssignment(Nodes.Node, RubySymbol, Nodes.Node[], Operand) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
buildAttrAssignCallArgs(Nodes.Node, Operand[], boolean) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
buildCallArgs(Nodes.Node, int[]) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
buildCallArgsArray(Nodes.Node[], int[]) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
buildCallKeywordArguments(Nodes.KeywordHashNode, int[]) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
buildColon2ForConstAsgnDeclNode(Nodes.Node, Variable, boolean) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
buildDRegex(Variable, Nodes.Node[], RegexpOptions) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
buildGetArgumentDefinition(Nodes.ArgumentsNode, String) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
buildGetDefinition(Nodes.Node) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
buildGetDefinition2(Nodes.Node) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
buildLazyWithOrder(Nodes.CallNode, Label, Label, boolean) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
buildOpAsgnOrWithDefined(Nodes.Node, IRBuilder.VoidCodeBlockOne, IRBuilder.CodeBlock) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
buildPatternEach(Label, Variable, Operand, Variable, Operand, Nodes.Node, boolean, boolean, Variable) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
buildWhenArgs(Nodes.WhenNode, Operand, Label, Set<IRubyObject>, Map<IRubyObject, Integer>) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
bytesToName(byte[]) - Method in class org.jruby.prism.parser.LoaderPrism
 

C

calculateSignature(Nodes.ParametersNode) - Static method in class org.jruby.prism.builder.IRBuilderPrism
 
canBeLazyMethod(Nodes.DefNode) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
capacity - Variable in class org.jruby.prism.parser.ParserBindingPrism.Buffer
 
containsVariableAssignment(Nodes.Node) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
CoverageLineVisitor - Class in org.jruby.prism.parser
 
createStaticScopeFrom(byte[][], StaticScope.Type) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
createStaticScopeFrom(String, RubySymbol[], StaticScope.Type, StaticScope) - Static method in class org.jruby.prism.builder.IRBuilderPrism
 

D

defaultVisit(Nodes.Node) - Method in class org.jruby.prism.parser.CoverageLineVisitor
 
dynamicPiece(Operand[], int, Nodes.Node, Encoding) - Method in class org.jruby.prism.builder.IRBuilderPrism
 

E

exceptionNodesFor(Nodes.RescueNode) - Method in class org.jruby.prism.builder.IRBuilderPrism
 

F

frozen_string(Nodes.Node) - Method in class org.jruby.prism.builder.IRBuilderPrism
 

G

getAST() - Method in class org.jruby.prism.parser.ParseResultPrism
 
getBuilder(IRManager, IRMethod) - Method in class org.jruby.prism.builder.LazyMethodDefinitionPrism
 
getBuilderFactory() - Method in class org.jruby.prism.ParserProviderPrism
 
getContainerFromCPath(Nodes.Node) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
getCoverageMode() - Method in class org.jruby.prism.parser.ParseResultPrism
 
getDynamicScope() - Method in class org.jruby.prism.parser.ParseResultPrism
 
getEncoding() - Method in class org.jruby.prism.parser.LoaderPrism
 
getEncoding() - Method in class org.jruby.prism.parser.ParseResultPrism
 
getEndLine() - Method in class org.jruby.prism.builder.LazyMethodDefinitionPrism
 
getFile() - Method in class org.jruby.prism.parser.ParseResultPrism
 
getInBody(Nodes.Node) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
getInExpression(Nodes.Node) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
getLine() - Method in class org.jruby.prism.parser.ParseResultPrism
 
getLine(Nodes.Node) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
getLineStub(ThreadContext, ParseResult, int) - Method in class org.jruby.prism.parser.ParserPrismBase
 
getLocalVariable(RubySymbol, int) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
getMethod() - Method in class org.jruby.prism.builder.LazyMethodDefinitionPrism
 
getMethodBody() - Method in class org.jruby.prism.builder.LazyMethodDefinitionPrism
 
getMethodData() - Method in class org.jruby.prism.builder.LazyMethodDefinitionPrism
 
getParser(Ruby) - Method in class org.jruby.prism.ParserProviderPrism
 
getRoot() - Method in class org.jruby.prism.parser.ParseResultPrism
 
getSource() - Method in class org.jruby.prism.parser.ParseResultPrism
 
getSourceNode() - Method in class org.jruby.prism.parser.ParseResultPrism
 
getStaticScope() - Method in class org.jruby.prism.parser.ParseResultPrism
 
getSymbols() - Method in class org.jruby.prism.parser.ParseResultPrism
 
getWhenLiteral(Nodes.Node) - Method in class org.jruby.prism.builder.IRBuilderPrism
 

H

hackPostExeSource(IRBuilder) - Method in class org.jruby.prism.builder.IRBuilderPrism
 

I

initialize(String) - Method in class org.jruby.prism.ParserProviderPrism
 
IRBuilderFactoryPrism - Class in org.jruby.prism.builder
 
IRBuilderFactoryPrism() - Constructor for class org.jruby.prism.builder.IRBuilderFactoryPrism
 
IRBuilderPrism - Class in org.jruby.prism.builder
 
IRBuilderPrism(IRManager, IRScope, IRBuilder, IRBuilder, Encoding) - Constructor for class org.jruby.prism.builder.IRBuilderPrism
 
isBareStar(Nodes.Node) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
isErrorInfoGlobal(Nodes.Node) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
isLiteralString(Nodes.Node) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
isNilRest(Nodes.Node) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
isSideEffectFree(Nodes.Node) - Method in class org.jruby.prism.builder.IRBuilderPrism
 

L

LazyMethodDefinitionPrism - Class in org.jruby.prism.builder
 
LazyMethodDefinitionPrism(Ruby, byte[], Nodes.Source, Encoding, Nodes.DefNode, IdentityHashMap<byte[], RubySymbol>) - Constructor for class org.jruby.prism.builder.LazyMethodDefinitionPrism
 
length - Variable in class org.jruby.prism.parser.ParserBindingPrism.Buffer
 
load() - Method in class org.jruby.prism.parser.LoaderPrism
 
LoaderPrism - Class in org.jruby.prism.parser
Extends Loader to override some things which are not generated directly for JRuby.

N

needsDefinitionCheck(Nodes.Node) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
newIRBuilder(IRManager, IRScope, IRBuilder, Encoding) - Method in class org.jruby.prism.builder.IRBuilderFactoryPrism
 
newIRBuilder(IRManager, IRScope, IRBuilder, IRBuilder, Encoding) - Method in class org.jruby.prism.builder.IRBuilderFactoryPrism
 

O

optRescueFor(Nodes.RescueNode) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
org.jruby.prism - package org.jruby.prism
 
org.jruby.prism.builder - package org.jruby.prism.builder
 
org.jruby.prism.parser - package org.jruby.prism.parser
 

P

parse(byte[], int, byte[]) - Method in class org.jruby.prism.parser.ParserPrismBase
 
parse(byte[], int, byte[]) - Method in class org.jruby.prism.parser.ParserPrismNative
 
parse(byte[], int, byte[]) - Method in class org.jruby.prism.parser.ParserPrismWasm
 
parse(String, int, InputStream, Encoding, DynamicScope, ParserType) - Method in class org.jruby.prism.parser.ParserPrismBase
 
parse(String, int, ByteList, DynamicScope, ParserType) - Method in class org.jruby.prism.parser.ParserPrismBase
 
ParserBindingPrism - Interface in org.jruby.prism.parser
JNR binding to prism.
ParserBindingPrism.Buffer - Class in org.jruby.prism.parser
 
ParseResultPrism - Class in org.jruby.prism.parser
 
ParseResultPrism(Ruby, String, byte[], Nodes.ProgramNode, Nodes.Source, Encoding, int) - Constructor for class org.jruby.prism.parser.ParseResultPrism
 
ParserPrismBase - Class in org.jruby.prism.parser
 
ParserPrismBase(Ruby) - Constructor for class org.jruby.prism.parser.ParserPrismBase
 
ParserPrismNative - Class in org.jruby.prism.parser
 
ParserPrismNative(Ruby, ParserBindingPrism) - Constructor for class org.jruby.prism.parser.ParserPrismNative
 
ParserPrismWasm - Class in org.jruby.prism.parser
 
ParserPrismWasm(Ruby) - Constructor for class org.jruby.prism.parser.ParserPrismWasm
 
ParserProviderPrism - Class in org.jruby.prism
 
ParserProviderPrism() - Constructor for class org.jruby.prism.ParserProviderPrism
 
parserTiming - Variable in class org.jruby.prism.parser.ParserPrismBase
 
pm_buffer_init(ParserBindingPrism.Buffer) - Method in interface org.jruby.prism.parser.ParserBindingPrism
 
pm_serialize_parse(ParserBindingPrism.Buffer, byte[], int, byte[]) - Method in interface org.jruby.prism.parser.ParserBindingPrism
 
putConstant(Nodes.ConstantPathNode, IRBuilder.CodeBlock) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
putConstant(Nodes.ConstantPathNode, Operand) - Method in class org.jruby.prism.builder.IRBuilderPrism
 

R

receiveBlockArg(Variable, Operand, int, boolean) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
receiveBlockArg(Nodes.Node) - Method in class org.jruby.prism.builder.IRBuilderPrism
Reify the implicit incoming block into a full Proc, for use as "block arg", but only if a block arg is specified in this scope's arguments.
receiveBlockArgs(Nodes.Node) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
receiveForArgs(Nodes.Node) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
receiveMethodArgs(Nodes.DefNode) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
receiveNonBlockArgs(Nodes.ParametersNode, Variable, boolean) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
receivePostArg(Nodes.Node, Variable, int, int, int, boolean, int) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
receivePreArg(Nodes.Node, Variable, int) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
referenceFor(Nodes.RescueNode) - Method in class org.jruby.prism.builder.IRBuilderPrism
 

S

setDynamicScope(DynamicScope) - Method in class org.jruby.prism.parser.ParseResultPrism
 
setRoot(Nodes.ProgramNode) - Method in class org.jruby.prism.parser.ParseResultPrism
 
setSourceFrom(IRBuilderPrism) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
setSourceFrom(Nodes.Source, byte[]) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
setSymbols(IdentityHashMap<byte[], RubySymbol>) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
setupCallClosure(Nodes.Node, Nodes.Node) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
symbol(Nodes.SymbolNode) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
symbols(byte[][]) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
symbols(byte[][]) - Method in class org.jruby.prism.parser.ParseResultPrism
 

T

topIRBuilder(IRManager, IRScope, ParseResult) - Method in class org.jruby.prism.builder.IRBuilderFactoryPrism
 

V

value - Variable in class org.jruby.prism.parser.ParserBindingPrism.Buffer
 
visitCallNode(Nodes.CallNode) - Method in class org.jruby.prism.parser.CoverageLineVisitor
 
visitClassNode(Nodes.ClassNode) - Method in class org.jruby.prism.parser.CoverageLineVisitor
 
visitDefNode(Nodes.DefNode) - Method in class org.jruby.prism.parser.CoverageLineVisitor
 
visitIfNode(Nodes.IfNode) - Method in class org.jruby.prism.parser.CoverageLineVisitor
 
visitModuleNode(Nodes.ModuleNode) - Method in class org.jruby.prism.parser.CoverageLineVisitor
 
visitStatementsNode(Nodes.StatementsNode) - Method in class org.jruby.prism.parser.CoverageLineVisitor
 
visitUnlessNode(Nodes.UnlessNode) - Method in class org.jruby.prism.parser.CoverageLineVisitor
 

W

whenBody(Nodes.WhenNode) - Method in class org.jruby.prism.builder.IRBuilderPrism
 
A B C D E F G H I L N O P R S T V W 
All Classes and Interfaces|All Packages