Class Nodes.AliasGlobalVariableNode

java.lang.Object
org.prism.Nodes.Node
org.prism.Nodes.AliasGlobalVariableNode
Enclosing class:
Nodes

public static final class Nodes.AliasGlobalVariableNode extends Nodes.Node
 Represents the use of the `alias` keyword to alias a global variable.

     alias $foo $bar
     ^^^^^^^^^^^^^^^
 
  • Field Details

    • new_name

      public final Nodes.Node new_name
       Represents the new name of the global variable that can be used after aliasing.
      
           alias $foo $bar
                 ^^^^
       
    • old_name

      public final Nodes.Node old_name
       Represents the old name of the global variable that can be used before aliasing.
      
           alias $foo $bar
                      ^^^^
       
  • Constructor Details

    • AliasGlobalVariableNode

      public AliasGlobalVariableNode(int startOffset, int length, Nodes.Node new_name, Nodes.Node old_name)
  • Method Details