Class Nodes.AliasMethodNode

java.lang.Object
org.prism.Nodes.Node
org.prism.Nodes.AliasMethodNode
Enclosing class:
Nodes

public static final class Nodes.AliasMethodNode extends Nodes.Node
 Represents the use of the `alias` keyword to alias a method.

     alias foo bar
     ^^^^^^^^^^^^^
 
  • Field Details

    • new_name

      public final Nodes.Node new_name
       Represents the new name of the method that will be aliased.
      
           alias foo bar
                 ^^^
      
           alias :foo :bar
                 ^^^^
      
           alias :"#{foo}" :"#{bar}"
                 ^^^^^^^^^
       
    • old_name

      public final Nodes.Node old_name
       Represents the old name of the method that will be aliased.
      
           alias foo bar
                     ^^^
      
           alias :foo :bar
                      ^^^^
      
           alias :"#{foo}" :"#{bar}"
                           ^^^^^^^^^
       
  • Constructor Details

    • AliasMethodNode

      public AliasMethodNode(int startOffset, int length, Nodes.Node new_name, Nodes.Node old_name)
  • Method Details