Class Nodes.CallNode

java.lang.Object
org.prism.Nodes.Node
org.prism.Nodes.CallNode
Enclosing class:
Nodes

public static final class Nodes.CallNode extends Nodes.Node
 Represents a method call, in all of the various forms that can take.

     foo
     ^^^

     foo()
     ^^^^^

     +foo
     ^^^^

     foo + bar
     ^^^^^^^^^

     foo.bar
     ^^^^^^^

     foo&.bar
     ^^^^^^^^
 
  • Field Details

    • flags

      public final short flags
    • receiver

      public final Nodes.Node receiver
       The object that the method is being called on. This can be either `nil` or any [non-void expression](https://github.com/ruby/prism/blob/main/docs/parsing_rules.md#non-void-expression).
      
           foo.bar
           ^^^
      
           +foo
            ^^^
      
           foo + bar
           ^^^
       
    • name

      public final org.jruby.RubySymbol name
       Represents the name of the method being called.
      
           foo.bar # name `:foo`
           ^^^
       
    • arguments

      public final Nodes.ArgumentsNode arguments
       Represents the arguments to the method call. These can be any [non-void expressions](https://github.com/ruby/prism/blob/main/docs/parsing_rules.md#non-void-expression).
      
           foo(bar)
               ^^^
       
    • block

      public final Nodes.Node block
       Represents the block that is being passed to the method.
      
           foo { |a| a }
               ^^^^^^^^^
       
  • Constructor Details

  • Method Details