Class Nodes.CallTargetNode
java.lang.Object
org.prism.Nodes.Node
org.prism.Nodes.CallTargetNode
- Enclosing class:
Nodes
Represents assigning to a method call.
foo.bar, = 1
^^^^^^^
begin
rescue => foo.bar
^^^^^^^
end
for foo.bar in baz do end
^^^^^^^
-
Field Summary
FieldsModifier and TypeFieldDescriptionfinal shortfinal org.jruby.RubySymbolRepresents the name of the method being called.final Nodes.NodeThe object that the method is being called on.Fields inherited from class org.prism.Nodes.Node
EMPTY_ARRAY, length, startOffset -
Constructor Summary
ConstructorsConstructorDescriptionCallTargetNode(int startOffset, int length, short flags, Nodes.Node receiver, org.jruby.RubySymbol name) -
Method Summary
Modifier and TypeMethodDescription<T> Taccept(AbstractNodeVisitor<T> visitor) booleanbooleanbooleanbooleanprotected String<T> voidvisitChildNodes(AbstractNodeVisitor<T> visitor) Methods inherited from class org.prism.Nodes.Node
endOffset, hasNewLineFlag, setNewLineFlag, setNewLineFlag, toString
-
Field Details
-
flags
public final short flags -
receiver
The object that the method is being called on. This can be any [non-void expression](https://github.com/ruby/prism/blob/main/docs/parsing_rules.md#non-void-expression). foo.bar = 1 ^^^ -
name
public final org.jruby.RubySymbol nameRepresents the name of the method being called. foo.bar = 1 # name `:foo` ^^^
-
-
Constructor Details
-
CallTargetNode
public CallTargetNode(int startOffset, int length, short flags, Nodes.Node receiver, org.jruby.RubySymbol name)
-
-
Method Details
-
isVariableCall
public boolean isVariableCall() -
isAttributeWrite
public boolean isAttributeWrite() -
isIgnoreVisibility
public boolean isIgnoreVisibility() -
visitChildNodes
- Specified by:
visitChildNodesin classNodes.Node
-
childNodes
- Specified by:
childNodesin classNodes.Node
-
accept
- Specified by:
acceptin classNodes.Node
-
toString
- Specified by:
toStringin classNodes.Node