Class Nodes.ClassVariableAndWriteNode
java.lang.Object
org.prism.Nodes.Node
org.prism.Nodes.ClassVariableAndWriteNode
- Enclosing class:
Nodes
Represents the use of the `&&=` operator for assignment to a class variable.
@@target &&= value
^^^^^^^^^^^^^^^^^^
-
Field Summary
FieldsModifier and TypeFieldDescriptionfinal org.jruby.RubySymbolThe name of the class variable, which is a `@@` followed by an [identifier](https://github.com/ruby/prism/blob/main/docs/parsing_rules.md#identifiers).final Nodes.NodeRepresents the value being assigned.Fields inherited from class org.prism.Nodes.Node
EMPTY_ARRAY, length, startOffset -
Constructor Summary
ConstructorsConstructorDescriptionClassVariableAndWriteNode(int startOffset, int length, org.jruby.RubySymbol name, Nodes.Node value) -
Method Summary
Modifier and TypeMethodDescription<T> Taccept(AbstractNodeVisitor<T> visitor) protected String<T> voidvisitChildNodes(AbstractNodeVisitor<T> visitor) Methods inherited from class org.prism.Nodes.Node
endOffset, hasNewLineFlag, setNewLineFlag, setNewLineFlag, toString
-
Field Details
-
name
public final org.jruby.RubySymbol nameThe name of the class variable, which is a `@@` followed by an [identifier](https://github.com/ruby/prism/blob/main/docs/parsing_rules.md#identifiers). @@target &&= value # name `:@@target` ^^^^^^^^ -
value
Represents the value being assigned. This can be any [non-void expression](https://github.com/ruby/prism/blob/main/docs/parsing_rules.md#non-void-expression). @@target &&= value ^^^^^
-
-
Constructor Details
-
ClassVariableAndWriteNode
public ClassVariableAndWriteNode(int startOffset, int length, org.jruby.RubySymbol name, Nodes.Node value)
-
-
Method Details
-
visitChildNodes
- Specified by:
visitChildNodesin classNodes.Node
-
childNodes
- Specified by:
childNodesin classNodes.Node
-
accept
- Specified by:
acceptin classNodes.Node
-
toString
- Specified by:
toStringin classNodes.Node
-