Class Nodes.ClassVariableReadNode
java.lang.Object
org.prism.Nodes.Node
org.prism.Nodes.ClassVariableReadNode
-
Field Summary
FieldsModifier and TypeFieldDescriptionfinal org.jruby.RubySymbolThe name of the class variable, which is a `@@` followed by an [identifier](https://github.com/ruby/prism/blob/main/docs/parsing_rules.md#identifiers).Fields inherited from class org.prism.Nodes.Node
EMPTY_ARRAY, length, startOffset -
Constructor Summary
ConstructorsConstructorDescriptionClassVariableReadNode(int startOffset, int length, org.jruby.RubySymbol name) -
Method Summary
Modifier and TypeMethodDescription<T> Taccept(AbstractNodeVisitor<T> visitor) protected String<T> voidvisitChildNodes(AbstractNodeVisitor<T> visitor) Methods inherited from class org.prism.Nodes.Node
endOffset, hasNewLineFlag, setNewLineFlag, setNewLineFlag, toString
-
Field Details
-
name
public final org.jruby.RubySymbol nameThe name of the class variable, which is a `@@` followed by an [identifier](https://github.com/ruby/prism/blob/main/docs/parsing_rules.md#identifiers). @@abc # name `:@@abc` @@_test # name `:@@_test`
-
-
Constructor Details
-
ClassVariableReadNode
public ClassVariableReadNode(int startOffset, int length, org.jruby.RubySymbol name)
-
-
Method Details
-
visitChildNodes
- Specified by:
visitChildNodesin classNodes.Node
-
childNodes
- Specified by:
childNodesin classNodes.Node
-
accept
- Specified by:
acceptin classNodes.Node
-
toString
- Specified by:
toStringin classNodes.Node
-