Class Nodes.ClassVariableWriteNode
java.lang.Object
org.prism.Nodes.Node
org.prism.Nodes.ClassVariableWriteNode
-
Field Summary
FieldsModifier and TypeFieldDescriptionfinal org.jruby.RubySymbolThe name of the class variable, which is a `@@` followed by an [identifier](https://github.com/ruby/prism/blob/main/docs/parsing_rules.md#identifiers).final Nodes.NodeThe value to write to the class variable.Fields inherited from class org.prism.Nodes.Node
EMPTY_ARRAY, length, startOffset -
Constructor Summary
ConstructorsConstructorDescriptionClassVariableWriteNode(int startOffset, int length, org.jruby.RubySymbol name, Nodes.Node value) -
Method Summary
Modifier and TypeMethodDescription<T> Taccept(AbstractNodeVisitor<T> visitor) protected String<T> voidvisitChildNodes(AbstractNodeVisitor<T> visitor) Methods inherited from class org.prism.Nodes.Node
endOffset, hasNewLineFlag, setNewLineFlag, setNewLineFlag, toString
-
Field Details
-
name
public final org.jruby.RubySymbol nameThe name of the class variable, which is a `@@` followed by an [identifier](https://github.com/ruby/prism/blob/main/docs/parsing_rules.md#identifiers). @@abc = 123 # name `@@abc` @@_test = :test # name `@@_test` -
value
The value to write to the class variable. This can be any [non-void expression](https://github.com/ruby/prism/blob/main/docs/parsing_rules.md#non-void-expression). @@foo = :bar ^^^^ @@_xyz = 123 ^^^
-
-
Constructor Details
-
ClassVariableWriteNode
public ClassVariableWriteNode(int startOffset, int length, org.jruby.RubySymbol name, Nodes.Node value)
-
-
Method Details
-
visitChildNodes
- Specified by:
visitChildNodesin classNodes.Node
-
childNodes
- Specified by:
childNodesin classNodes.Node
-
accept
- Specified by:
acceptin classNodes.Node
-
toString
- Specified by:
toStringin classNodes.Node
-