Class Nodes.FloatNode
java.lang.Object
org.prism.Nodes.Node
org.prism.Nodes.FloatNode
-
Field Summary
FieldsModifier and TypeFieldDescriptionfinal doubleThe value of the floating point number as a Float.Fields inherited from class org.prism.Nodes.Node
EMPTY_ARRAY, length, startOffset -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescription<T> Taccept(AbstractNodeVisitor<T> visitor) protected String<T> voidvisitChildNodes(AbstractNodeVisitor<T> visitor) Methods inherited from class org.prism.Nodes.Node
endOffset, hasNewLineFlag, setNewLineFlag, setNewLineFlag, toString
-
Field Details
-
value
public final double valueThe value of the floating point number as a Float.
-
-
Constructor Details
-
FloatNode
public FloatNode(int startOffset, int length, double value)
-
-
Method Details
-
visitChildNodes
- Specified by:
visitChildNodesin classNodes.Node
-
childNodes
- Specified by:
childNodesin classNodes.Node
-
accept
- Specified by:
acceptin classNodes.Node
-
toString
- Specified by:
toStringin classNodes.Node
-