Class Nodes.GlobalVariableReadNode

java.lang.Object
org.prism.Nodes.Node
org.prism.Nodes.GlobalVariableReadNode
Enclosing class:
Nodes

public static final class Nodes.GlobalVariableReadNode extends Nodes.Node
 Represents referencing a global variable.

     $foo
     ^^^^
 
  • Field Details

    • name

      public final org.jruby.RubySymbol name
       The name of the global variable, which is a `$` followed by an [identifier](https://github.com/ruby/prism/blob/main/docs/parsing_rules.md#identifier). Alternatively, it can be one of the special global variables designated by a symbol.
      
           $foo   # name `:$foo`
      
           $_Test # name `:$_Test`
       
  • Constructor Details

    • GlobalVariableReadNode

      public GlobalVariableReadNode(int startOffset, int length, org.jruby.RubySymbol name)
  • Method Details