Class Nodes.ImplicitNode

java.lang.Object
org.prism.Nodes.Node
org.prism.Nodes.ImplicitNode
Enclosing class:
Nodes

public static final class Nodes.ImplicitNode extends Nodes.Node
 Represents a node that is implicitly being added to the tree but doesn't correspond directly to a node in the source.

     { foo: }
       ^^^^

     { Foo: }
       ^^^^

     foo in { bar: }
              ^^^^