Class Nodes.IntegerBaseFlags
java.lang.Object
org.prism.Nodes.IntegerBaseFlags
- All Implemented Interfaces:
Comparable<Nodes.IntegerBaseFlags>
- Enclosing class:
Nodes
public static final class Nodes.IntegerBaseFlags
extends Object
implements Comparable<Nodes.IntegerBaseFlags>
Flags for integer nodes that correspond to the base of the integer.
-
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final shortstatic final shortstatic final shortstatic final short -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionintcompareTo(Nodes.IntegerBaseFlags other) booleaninthashCode()booleanisBinary()static booleanisBinary(short flags) booleanstatic booleanisDecimal(short flags) booleanstatic booleanisHexadecimal(short flags) booleanisOctal()static booleanisOctal(short flags)
-
Field Details
-
BINARY
public static final short BINARY- See Also:
-
DECIMAL
public static final short DECIMAL- See Also:
-
OCTAL
public static final short OCTAL- See Also:
-
HEXADECIMAL
public static final short HEXADECIMAL- See Also:
-
-
Constructor Details
-
IntegerBaseFlags
public IntegerBaseFlags(short flags)
-
-
Method Details
-
isBinary
public static boolean isBinary(short flags) -
isDecimal
public static boolean isDecimal(short flags) -
isOctal
public static boolean isOctal(short flags) -
isHexadecimal
public static boolean isHexadecimal(short flags) -
hashCode
-
equals
-
compareTo
- Specified by:
compareToin interfaceComparable<Nodes.IntegerBaseFlags>
-
isBinary
public boolean isBinary() -
isDecimal
public boolean isDecimal() -
isOctal
public boolean isOctal() -
isHexadecimal
public boolean isHexadecimal()
-