Class Nodes.ShareableConstantNode

java.lang.Object
org.prism.Nodes.Node
org.prism.Nodes.ShareableConstantNode
Enclosing class:
Nodes

public static final class Nodes.ShareableConstantNode extends Nodes.Node
 This node wraps a constant write to indicate that when the value is written, it should have its shareability state modified.

     # shareable_constant_value: literal
     C = { a: 1 }
     ^^^^^^^^^^^^
 
  • Field Details

    • flags

      public final short flags
    • write

      public final Nodes.Node write
       The constant write that should be modified with the shareability state.
       
  • Constructor Details

    • ShareableConstantNode

      public ShareableConstantNode(int startOffset, int length, short flags, Nodes.Node write)
  • Method Details