Uses of Class
org.prism.Nodes.InterpolatedStringNodeFlags
Packages that use Nodes.InterpolatedStringNodeFlags
-
Uses of Nodes.InterpolatedStringNodeFlags in org.prism
Classes in org.prism that implement interfaces with type arguments of type Nodes.InterpolatedStringNodeFlagsModifier and TypeClassDescriptionstatic final classFlags for interpolated string nodes that indicated mutability if they are also marked as literals.Methods in org.prism with parameters of type Nodes.InterpolatedStringNodeFlagsModifier and TypeMethodDescriptionintNodes.InterpolatedStringNodeFlags.compareTo(Nodes.InterpolatedStringNodeFlags other)