Uses of Enum Class
org.prism.ParsingOptions.CommandLine
Packages that use ParsingOptions.CommandLine
-
Uses of ParsingOptions.CommandLine in org.prism
Subclasses with type arguments of type ParsingOptions.CommandLine in org.prismModifier and TypeClassDescriptionstatic enumThe command line options that can be passed to the parser.Methods in org.prism that return ParsingOptions.CommandLineModifier and TypeMethodDescriptionstatic ParsingOptions.CommandLineReturns the enum constant of this class with the specified name.static ParsingOptions.CommandLine[]ParsingOptions.CommandLine.values()Returns an array containing the constants of this enum class, in the order they are declared.Method parameters in org.prism with type arguments of type ParsingOptions.CommandLineModifier and TypeMethodDescriptionstatic byte[]ParsingOptions.serialize(byte[] filepath, int line, byte[] encoding, boolean frozenStringLiteral, EnumSet<ParsingOptions.CommandLine> commandLine, ParsingOptions.SyntaxVersion version, boolean encodingLocked, boolean mainScript, boolean partialScript, byte[][][] scopes) static byte[]ParsingOptions.serialize(byte[] filepath, int line, byte[] encoding, boolean frozenStringLiteral, EnumSet<ParsingOptions.CommandLine> commandLine, ParsingOptions.SyntaxVersion version, boolean encodingLocked, boolean mainScript, boolean partialScript, ParsingOptions.Scope[] scopes) Serialize parsing options into byte array.