Uses of Enum Class
org.prism.ParsingOptions.SyntaxVersion
Packages that use ParsingOptions.SyntaxVersion
-
Uses of ParsingOptions.SyntaxVersion in org.prism
Subclasses with type arguments of type ParsingOptions.SyntaxVersion in org.prismModifier and TypeClassDescriptionstatic enumThe version of Ruby syntax that we should be parsing with.Methods in org.prism that return ParsingOptions.SyntaxVersionModifier and TypeMethodDescriptionstatic ParsingOptions.SyntaxVersionReturns the enum constant of this class with the specified name.static ParsingOptions.SyntaxVersion[]ParsingOptions.SyntaxVersion.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in org.prism with parameters of type ParsingOptions.SyntaxVersionModifier and TypeMethodDescriptionstatic byte[]ParsingOptions.serialize(byte[] filepath, int line, byte[] encoding, boolean frozenStringLiteral, EnumSet<ParsingOptions.CommandLine> commandLine, ParsingOptions.SyntaxVersion version, boolean encodingLocked, boolean mainScript, boolean partialScript, byte[][][] scopes) static byte[]ParsingOptions.serialize(byte[] filepath, int line, byte[] encoding, boolean frozenStringLiteral, EnumSet<ParsingOptions.CommandLine> commandLine, ParsingOptions.SyntaxVersion version, boolean encodingLocked, boolean mainScript, boolean partialScript, ParsingOptions.Scope[] scopes) Serialize parsing options into byte array.