Class Nodes.AliasGlobalVariableNode
java.lang.Object
org.prism.Nodes.Node
org.prism.Nodes.AliasGlobalVariableNode
- Enclosing class:
Nodes
Represents the use of the `alias` keyword to alias a global variable.
alias $foo $bar
^^^^^^^^^^^^^^^
-
Field Summary
FieldsModifier and TypeFieldDescriptionfinal Nodes.NodeRepresents the new name of the global variable that can be used after aliasing.final Nodes.NodeRepresents the old name of the global variable that can be used before aliasing.Fields inherited from class org.prism.Nodes.Node
EMPTY_ARRAY, length, startOffset -
Constructor Summary
ConstructorsConstructorDescriptionAliasGlobalVariableNode(int startOffset, int length, Nodes.Node new_name, Nodes.Node old_name) -
Method Summary
Modifier and TypeMethodDescription<T> Taccept(AbstractNodeVisitor<T> visitor) protected String<T> voidvisitChildNodes(AbstractNodeVisitor<T> visitor) Methods inherited from class org.prism.Nodes.Node
endOffset, hasNewLineFlag, setNewLineFlag, setNewLineFlag, toString
-
Field Details
-
new_name
Represents the new name of the global variable that can be used after aliasing. alias $foo $bar ^^^^ -
old_name
Represents the old name of the global variable that can be used before aliasing. alias $foo $bar ^^^^
-
-
Constructor Details
-
AliasGlobalVariableNode
public AliasGlobalVariableNode(int startOffset, int length, Nodes.Node new_name, Nodes.Node old_name)
-
-
Method Details
-
visitChildNodes
- Specified by:
visitChildNodesin classNodes.Node
-
childNodes
- Specified by:
childNodesin classNodes.Node
-
accept
- Specified by:
acceptin classNodes.Node
-
toString
- Specified by:
toStringin classNodes.Node
-