Class Nodes.AliasMethodNode
java.lang.Object
org.prism.Nodes.Node
org.prism.Nodes.AliasMethodNode
- Enclosing class:
Nodes
Represents the use of the `alias` keyword to alias a method.
alias foo bar
^^^^^^^^^^^^^
-
Field Summary
FieldsModifier and TypeFieldDescriptionfinal Nodes.NodeRepresents the new name of the method that will be aliased.final Nodes.NodeRepresents the old name of the method that will be aliased.Fields inherited from class org.prism.Nodes.Node
EMPTY_ARRAY, length, startOffset -
Constructor Summary
ConstructorsConstructorDescriptionAliasMethodNode(int startOffset, int length, Nodes.Node new_name, Nodes.Node old_name) -
Method Summary
Modifier and TypeMethodDescription<T> Taccept(AbstractNodeVisitor<T> visitor) protected String<T> voidvisitChildNodes(AbstractNodeVisitor<T> visitor) Methods inherited from class org.prism.Nodes.Node
endOffset, hasNewLineFlag, setNewLineFlag, setNewLineFlag, toString
-
Field Details
-
new_name
Represents the new name of the method that will be aliased. alias foo bar ^^^ alias :foo :bar ^^^^ alias :"#{foo}" :"#{bar}" ^^^^^^^^^ -
old_name
Represents the old name of the method that will be aliased. alias foo bar ^^^ alias :foo :bar ^^^^ alias :"#{foo}" :"#{bar}" ^^^^^^^^^
-
-
Constructor Details
-
AliasMethodNode
-
-
Method Details
-
visitChildNodes
- Specified by:
visitChildNodesin classNodes.Node
-
childNodes
- Specified by:
childNodesin classNodes.Node
-
accept
- Specified by:
acceptin classNodes.Node
-
toString
- Specified by:
toStringin classNodes.Node
-