Class Nodes.ShareableConstantNode
java.lang.Object
org.prism.Nodes.Node
org.prism.Nodes.ShareableConstantNode
- Enclosing class:
Nodes
This node wraps a constant write to indicate that when the value is written, it should have its shareability state modified.
# shareable_constant_value: literal
C = { a: 1 }
^^^^^^^^^^^^
-
Field Summary
FieldsModifier and TypeFieldDescriptionfinal shortfinal Nodes.NodeThe constant write that should be modified with the shareability state.Fields inherited from class org.prism.Nodes.Node
EMPTY_ARRAY, length, startOffset -
Constructor Summary
ConstructorsConstructorDescriptionShareableConstantNode(int startOffset, int length, short flags, Nodes.Node write) -
Method Summary
Modifier and TypeMethodDescription<T> Taccept(AbstractNodeVisitor<T> visitor) booleanbooleanbooleanprotected String<T> voidvisitChildNodes(AbstractNodeVisitor<T> visitor) Methods inherited from class org.prism.Nodes.Node
endOffset, hasNewLineFlag, setNewLineFlag, setNewLineFlag, toString
-
Field Details
-
flags
public final short flags -
write
The constant write that should be modified with the shareability state.
-
-
Constructor Details
-
ShareableConstantNode
-
-
Method Details
-
isLiteral
public boolean isLiteral() -
isExperimentalEverything
public boolean isExperimentalEverything() -
isExperimentalCopy
public boolean isExperimentalCopy() -
visitChildNodes
- Specified by:
visitChildNodesin classNodes.Node
-
childNodes
- Specified by:
childNodesin classNodes.Node
-
accept
- Specified by:
acceptin classNodes.Node
-
toString
- Specified by:
toStringin classNodes.Node
-